##################----DATA ORGANIZATION----#######################
#SETUP ENVIRONMENT
library(ggmap)
library(readxl)
library(lubridate)
library(reshape2)
library(ggplot2)
library(gstat)
library(maptools)
library(zoo)
library(rcompanion)
library(mlmRev)
ENVC <- read_excel("/Users/veronica/Desktop/Full Export 19Oct18 Copy.xlsx")
ENVCL <- read_excel("/Users/veronica/Desktop/Full Export 19Oct18 Copy LOD.xlsx")

#Remove duplicates
library(tidyverse)
ENVC<-ENVC %>% distinct()
ENVCL<-ENVCL %>% distinct()

#Cleanup data
ENVC$ven=replace(ENVC$ven, ENVC$ven == -999, NaN)
ENVC$Species=replace(ENVC$Species, ENVC$Species == "herring", "Herring")
ENVC$Latitude=replace(ENVC$Latitude, ENVC$Latitude == 0, NaN)
ENVC$Longitude=replace(ENVC$Longitude, ENVC$Longitude== 0, NaN)
ENVC$Species=replace(ENVC$Species, ENVC$Species == "sockeye", "Sockeye")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex =="m", "M")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex =="PM", "M")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "U/M", "U")
ENVC$HatcheryWild=replace(ENVC$HatcheryWild,ENVC$HatcheryWild == "wild", "Wild")
ENVC$Date <- as.Date(ENVC$Date)
year(ENVC$Date) <- 0
ENVC$Month<-month(as.POSIXlt(ENVC$Date, format="%d/%m/%Y"))
ENVC$Month<-month.abb[ENVC$Month]
ENVC$Date <- as.POSIXct(ENVC$Date)
yq <- as.yearqtr(as.yearmon(ENVC$Date, "%m/%d/%Y") + 1/12)
ENVC$venval<-ENVC$ven #save this to analyize ven quantitatively later

#Cleanup data
ENVCL$ven=replace(ENVCL$ven, ENVCL$ven == -999, NaN)
ENVCL$Species=replace(ENVCL$Species, ENVCL$Species == "herring", "Herring")
ENVCL$Latitude=replace(ENVCL$Latitude, ENVCL$Latitude == 0, NaN)
ENVCL$Longitude=replace(ENVCL$Longitude, ENVCL$Longitude== 0, NaN)
ENVCL$Species=replace(ENVCL$Species, ENVCL$Species == "sockeye", "Sockeye")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex =="m", "M")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex =="PM", "M")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "U/M", "U")
ENVCL$HatcheryWild=replace(ENVCL$HatcheryWild,ENVCL$HatcheryWild == "wild", "Wild")
ENVCL$Date <- as.Date(ENVCL$Date)
year(ENVCL$Date) <- 0
ENVCL$Date <- as.POSIXct(ENVCL$Date)
ENVCL$Month<-month(as.POSIXlt(ENVCL$Date, format="%d/%m/%Y"))
ENVCL$Month<-month.abb[ENVCL$Month]
yq <- as.yearqtr(as.yearmon(ENVCL$Date, "%m/%d/%Y") + 1/12)
ENVCL$venval<-ENVCL$ven #save this to analyize ven quantitatively later


#FOR MOST ANALYSIS USE ONLY MIXED TISSUE
NM<-subset(ENVC,ENVC$Tissue!="Mixed")
NML<-subset(ENVCL,ENVCL$Tissue!="Mixed")

ENVC<-subset(ENVC,ENVC$Tissue=="Mixed")
ENVCL<-subset(ENVCL,ENVCL$Tissue=="Mixed")

#Remove duplicate fish, replace venval with mean if there are multiple measurements
dat3 <- ENVC[!(!duplicated(ENVC[,3], fromLast=T) & !duplicated(ENVC[, 3])),] 
dat3<-dat3[!is.na(dat3$venval), ]
dat3<-aggregate(venval~Fish,dat3,mean)
ENVC<-ENVC[!duplicated(ENVC$Fish), ]
index<-dat3[!duplicated(dat3$Fish), ]
j<-match(c(index[,1]),ENVC$Fish)
ENVC$venval<-replace(ENVC$venval,j,index$venval)

dat3L <- ENVCL[!(!duplicated(ENVCL[,3], fromLast=T) & !duplicated(ENVCL[, 3])),] 
dat3L<-dat3L[!is.na(dat3L$venval), ]
dat3L<-aggregate(venval~Fish,dat3L,mean)
ENVCL<-ENVCL[!duplicated(ENVCL$Fish), ]
indexL<-dat3L[!duplicated(dat3L$Fish), ]
jL<-match(c(indexL[,1]),ENVCL$Fish)
ENVCL$venval<-replace(ENVCL$venval,jL,indexL$venval)

#Create discrete cutoffs for analysis and mapping
ENVC$cuts <- cut(ENVC$ven, c(-Inf, 0, 5, 10, 100, 1000,Inf), labels=1:6)
ENVC$ven[ ENVC$ven >0 ] <- "positive" #for now just look at ENV presence or absence
ENVC$ven[ ENVC$ven <=0 ] <- "negative"


ENVCL$cuts <- cut(ENVCL$venval, c(-Inf, 0, 5, 10, 100, 1000,Inf), labels=1:6)
ENVCL$ven[ ENVCL$ven >0 ] <- "positive" #for now just look at ENV presence or absence
ENVCL$ven[ ENVCL$ven <=0 ] <- "negative"

ENVC$Species=as.factor(ENVC$Species)
ENVCL$Species=as.factor(ENVCL$Species)
#group all species together, regardless if AMD classified
ENVC$Species=replace(ENVC$Species, ENVC$Species == "Coho-AMD", "Coho")
ENVC$Species=replace(ENVC$Species, ENVC$Species== "Atlantic-AMD", "Atlantic")
ENVC$Species=replace(ENVC$Species, ENVC$Species == "Chinook-AMD", "Chinook")
ENVC$Species<-droplevels(ENVC$Species)
ENVCL$Species=replace(ENVCL$Species, ENVCL$Species == "Coho-AMD", "Coho")
ENVCL$Species=replace(ENVCL$Species, ENVCL$Species== "Atlantic-AMD", "Atlantic")
ENVCL$Species=replace(ENVCL$Species, ENVCL$Species == "Chinook-AMD", "Chinook")
ENVCL$Species<-droplevels(ENVCL$Species)

ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == ",", NA)
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "/", NA)
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "f", "F")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "F?", "F")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "m", "M")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "m?", "M")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "M?", "M")
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "Missing Fish", NA)
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "N", NA)
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "NA", NA)
ENVC$Sex=replace(ENVC$Sex,ENVC$Sex == "U/M", "U")
ENVC$Sex=replace(ENVC$Sex,is.na(ENVC$Sex), "U")
ENVC$Sex=as.factor(ENVC$Sex)
ENVC$Sex=droplevels(ENVC$Sex)

ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == ",", NA)
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "/", NA)
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "f", "F")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "F?", "F")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "m", "M")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "m?", "M")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "M?", "M")
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "Missing Fish", NA)
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "N", NA)
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "NA", NA)
ENVCL$Sex=replace(ENVCL$Sex,ENVCL$Sex == "U/M", "U")
ENVCL$Sex=replace(ENVCL$Sex,is.na(ENVCL$Sex), "U")
ENVCL$Sex=as.factor(ENVCL$Sex)
ENVCL$Sex=droplevels(ENVCL$Sex)

#ABOUT THE DATASET
#NUMBER UNIQUE FISH=21677
#NUMBER DUPLICATES REMOVED=1330
#TISSUE TYPES: heart(470),brain(615),gill(400),liver(1669),spleen(8),mixed(19823),na(22)=23007

#to look at distribution in different tissue
NM$venval<-NM$ven
NML$venval<-NML$ven

NM$ven[NM$ven >0 ] <- "positive" #for now just look at ENV presence or absence
NM$ven[ NM$ven <=0 ] <- "negative"

NML$ven[NML$ven >0 ] <- "positive" #for now just look at ENV presence or absence
NML$ven[ NML$ven <=0 ] <- "negative"

NML$Tissue<-as.factor(NML$Tissue)
NM$Tissue<-as.factor(NM$Tissue)
prop<-numeric(1)
N<-numeric(1)
Tissue<-numeric(1)
j=1
for(i in levels(NM$Tissue)){
  new<-subset(NM, NM$Tissue==i)
  pos<-sum(new$ven=="positive")
  neg<-sum(new$ven=="negative")
  prop[j]<-pos
  Tissue[j]=i
  N[j]<-pos+neg
  j=j+1
}

#Sample sizes are small for many of these fish, analyze only herring and salmon:
#REMOVE THIS PART TO SEE ALL-SPECIES PLOTS
#ENVC<-subset(ENVC,ENVC$Species!="Herring") #to see if herring determine this
ENVCL<-subset(ENVCL,ENVCL$Species!="Anchovy")
ENVCL<-subset(ENVCL,ENVCL$Species!="Eulachon")
ENVCL<-subset(ENVCL,ENVCL$Species!="Pacific Cod")
ENVCL<-subset(ENVCL,ENVCL$Species!="Pollock")
ENVCL<-subset(ENVCL,ENVCL$Species!="Rockfish")
ENVCL<-subset(ENVCL,ENVCL$Species!="Sandlance")
ENVCL<-subset(ENVCL,ENVCL$Species!="Sardine")
ENVCL<-subset(ENVCL,ENVCL$Species!="Shiner Perch")
ENVCL<-subset(ENVCL,ENVCL$Species!="Stickleback")

ENVC<-subset(ENVC,ENVC$Species!="Anchovy")
ENVC<-subset(ENVC,ENVC$Species!="Eulachon")
ENVC<-subset(ENVC,ENVC$Species!="Pacific Cod")
ENVC<-subset(ENVC,ENVC$Species!="Pollock")
ENVC<-subset(ENVC,ENVC$Species!="Rockfish")
ENVC<-subset(ENVC,ENVC$Species!="Sandlance")
ENVC<-subset(ENVC,ENVC$Species!="Sardine")
ENVC<-subset(ENVC,ENVC$Species!="Shiner Perch")
ENVC<-subset(ENVC,ENVC$Species!="Stickleback")

##################----MAPPING----#######################
#BIG MAP
lon1=c(-140,-121)
lat1=c(40, 68)
#SMALL MAP
lon1=c(-132,-120)
lat1=c(48, 51)
register_google(key = "AIzaSyAX9PjPZ4d2UJOyI8X66uHgZgZrJEeX2T4")
sbbox <- make_bbox(lon1, lat1, f = .1)
env_map <- get_map(location = sbbox, maptype = "terrain", source = "google", color="bw")

#HEAT MAP
coords<-data.frame(ENVC$Latitude, ENVC$Longitude,ENVC$cuts)
coords<-na.omit(coords)
coordinates(coords) <- ~ENVC.Longitude + ENVC.Latitude
#change this along with map size
x_range <- as.numeric(c(-140, -121)) 
y_range <- as.numeric(c(40, 68))
grd <- expand.grid(x = seq(from = x_range[1],to = x_range[2], by = 0.1),y = seq(from = y_range[1],to = y_range[2], by = 0.1))
coordinates(grd) <- ~x + y
gridded(grd) <- TRUE
plot(grd, cex = 1.5, col = "grey")
plot(coords, pch = 15,col = "red",cex = 1,add = TRUE)
idw_pow1 <- idw(formula = ENVC.cuts ~ 1,locations = coords,newdata = grd,idp = 3)
idw.output = as.data.frame(idw_pow1)
coords<-data.frame(coords)
heat<-plot(idw_pow1,col = terrain.colors(55))
#DIFFERENT VERSIONS
p2 <-ggmap(env_map) + geom_tile(data = idw.output, alpha = 0.6, aes(x = x, y = y, fill = (var1.pred)))
p2+ scale_fill_gradientn(colors=c("blue","cyan","green", "yellow", "orange", "red"))
#See individual data points by transparency
p3 <-ggmap(env_map) + geom_tile(data = idw.output, alpha = 0.4, aes(x = x, y = y, fill = var1.pred))+geom_point(data = coords, aes(x = ENVC.Longitude, y = ENVC.Latitude,size=ENVC.cuts), alpha=0.1,color="black")
p3+ scale_fill_gradientn(colors=c("blue","cyan","green", "yellow", "orange", "red"))+scale_size_manual(values=c(0.2,0.8,1.4,2,2.6,3.2))
#Alternative heat map with data points
p2 <-ggmap(env_map) +geom_point(data = coords, aes(x = ENVC.Longitude, y = ENVC.Latitude, size=ENVC.cuts,color=ENVC.cuts), alpha=0.3)
p2+scale_size_manual(values=c(0.2,1,1.8,2.6,3.2,4))+scale_color_brewer(palette = "BrBG")
#Alternative heat map with data points jittered
p2 <-ggmap(env_map) +geom_jitter(width = 0.2, height = 0.2, data = coords, aes(x = ENVC.Longitude, y = ENVC.Latitude,size=ENVC.cuts, color=ENVC.cuts), alpha=0.5)
p2+scale_size_manual(values=c(0.05,1,1,1,1,1))+scale_color_brewer(palette = "BrBG")



#OTHER MAPS
#See region map
map3=ggmap(env_map) +geom_point(data = ENVC, aes(x = Longitude, y = Latitude, color=Catch_Region), size=0.2)
map3
#4Red dots for positive locations
ENVCL$ven<-as.factor(ENVCL$ven)
ENVCL$ven=replace(ENVCL$ven, is.na(ENVCL$ven), NaN)
ENVCL$ven<-droplevels(ENVCL$ven)
map4=ggmap(env_map) +geom_point(data = ENVCL, aes(x = Longitude, y = Latitude, size=ven,color=ven)) +scale_size_manual(values=c(.2,.2,2))+scale_color_manual(values=c("black","black","red"))
map4


#########################----PLOTS----###########################
ENVC$ven <- factor(ENVC$ven)
ENVC$Species<- factor(ENVC$Species)
ENVC$HatcheryWild<- factor(ENVC$HatcheryWild)
ENVC$Sex<- factor(ENVC$Sex)
ENVC$Catch_Region=as.factor(ENVC$Catch_Region)
ENVC$SmAd=as.factor(ENVC$SmAd)
ENVC$Year<-as.factor(ENVC$Year)
ENVC$SWFW<-factor(ENVC$SWFW)
ENVC$Month<-factor(ENVC$Month)

ENVCL$ven <- factor(ENVCL$ven)
ENVCL$Species<- factor(ENVCL$Species)
ENVCL$HatcheryWild<- factor(ENVCL$HatcheryWild)
ENVCL$Sex<- factor(ENVCL$Sex)
ENVCL$SmAd=as.factor(ENVCL$SmAd)
ENVCL$Catch_Region<-as.factor(ENVCL$Catch_Region)
ENVCL$Year<-as.factor(ENVCL$Year)
ENVCL$SWFW<-factor(ENVCL$SWFW)
ENVCL$Month<-factor(ENVCL$Month)


#Instructions:
#1)replace ENVC$Category with category of interest 
#2)replace samp repeat value to number of levels in category
#3)change the values in: meltd$proportion2[(10:18)]=0 to appropriate values
#4)Adjust plot scale if values are not plotted

C3<-numeric(2)
C1<-numeric(2)
C2<-numeric(2)
CH3<-numeric(2)
CH1<-numeric(2)
CH2<-numeric(2)
H3<-numeric(2)
H1<-numeric(2)
H2<-numeric(2)
S3<-numeric(2)
S1<-numeric(2)
S2<-numeric(2)
d<-numeric(2)
A3<-numeric(2)
A1<-numeric(2)
A2<-numeric(2)
Chu3<-numeric(2)
Chu1<-numeric(2)
Chu2<-numeric(2)
P3<-numeric(2)
P1<-numeric(2)
P2<-numeric(2)
j=1
for(i in levels(ENVC$HatcheryWild)){
  new<-subset(ENVC, ENVC$HatcheryWild==i)
  Coho <- subset(new, new$Species=="Coho")
  C1[j]<-sum(Coho$ven == "negative",na.rm=TRUE) #1553
  C2[j]<-sum(Coho$ven == "positive",na.rm=TRUE) #63
  C3 [j]<-C2[j]/(C1[j]+C2[j])
  
  Chinook <- subset(new, new$Species=="Chinook")
  CH1[j]<-sum(Chinook$ven == "negative",na.rm=TRUE) #4842
  CH2[j]<-sum(Chinook$ven == "positive",na.rm=TRUE) #380 
  CH3[j]<-CH2[j]/(CH1[j]+CH2[j])
  
  Herring <- subset(new, new$Species=="Herring")
  H1[j]<-sum(Herring$ven == "negative",na.rm=TRUE) #165
  H2[j]<-sum(Herring$ven == "positive",na.rm=TRUE) #25
  H3[j]<-H2[j]/(H1[j]+H2[j])
  
  Sockeye <- subset(new, new$Species=="Sockeye")
  S1[j]<-sum(Sockeye$ven == "negative",na.rm=TRUE) #2841
  S2[j]<-sum(Sockeye$ven == "positive",na.rm=TRUE) #225
  S3[j]<-S2[j]/(S1[j]+S2[j])
  
  Atlantic <- subset(new, new$Species=="Atlantic")
  A1[j]<-sum(Atlantic$ven == "negative",na.rm=TRUE) #1553
  A2[j]<-sum(Atlantic$ven == "positive",na.rm=TRUE) #63
  A3[j]<-A2[j]/(A1[j]+A2[j])
  
  Chum <- subset(new, new$Species=="Chum")
  Chu1[j]<-sum(Chum$ven == "negative",na.rm=TRUE) #1553
  Chu2[j]<-sum(Chum$ven == "positive",na.rm=TRUE) #63
  Chu3[j]<-Chu2[j]/(Chu1[j]+Chu2[j])
  
  Pink <- subset(new, new$Species=="Pink")
  P1[j]<-sum(Pink$ven == "negative",na.rm=TRUE) #1553
  P2[j]<-sum(Pink$ven == "positive",na.rm=TRUE) #63
  P3[j]<-P2[j]/(P1[j]+P2[j])
  d[j] <-(i)
  j=j+1
}

CL3<-numeric(2)
CL1<-numeric(2)
CL2<-numeric(2)
CHL3<-numeric(2)
CHL1<-numeric(2)
CHL2<-numeric(2)
HL3<-numeric(2)
HL1<-numeric(2)
HL2<-numeric(2)
SL3<-numeric(2)
SL1<-numeric(2)
SL2<-numeric(2)
dL<-numeric(2)
AL3<-numeric(2)
AL1<-numeric(2)
AL2<-numeric(2)
ChuL3<-numeric(2)
ChuL1<-numeric(2)
ChuL2<-numeric(2)
PL3<-numeric(2)
PL1<-numeric(2)
PL2<-numeric(2)

j=1
for(i in levels(ENVCL$HatcheryWild)){
  new<-subset(ENVCL, ENVCL$HatcheryWild==i)
  Coho <- subset(new, new$Species=="Coho")
  CL1[j]<-sum(Coho$ven == "negative",na.rm=TRUE) #1553
  CL2[j]<-sum(Coho$ven == "positive",na.rm=TRUE) #63
  CL3[j]<-CL2[j]/(CL1[j]+CL2[j])
  
  Chinook <- subset(new, new$Species=="Chinook")
  CHL1[j]<-sum(Chinook$ven == "negative",na.rm=TRUE) #4842
  CHL2[j]<-sum(Chinook$ven == "positive",na.rm=TRUE) #380 
  CHL3[j]<-CHL2[j]/(CHL1[j]+CHL2[j])
  
  Herring <- subset(new, new$Species=="Herring")
  HL1[j]<-sum(Herring$ven == "negative",na.rm=TRUE) #165
  HL2[j]<-sum(Herring$ven == "positive",na.rm=TRUE) #25
  HL3[j]<-HL2[j]/(HL1[j]+HL2[j])
  
  Sockeye <- subset(new, new$Species=="Sockeye")
  SL1[j]<-sum(Sockeye$ven == "negative",na.rm=TRUE) #2841
  SL2[j]<-sum(Sockeye$ven == "positive",na.rm=TRUE) #225
  SL3[j]<-SL2[j]/(SL1[j]+SL2[j])
  
  Atlantic <- subset(new, new$Species=="Atlantic")
  AL1[j]<-sum(Atlantic$ven == "negative",na.rm=TRUE) #1553
  AL2[j]<-sum(Atlantic$ven == "positive",na.rm=TRUE) #63
  AL3[j]<-AL2[j]/(AL1[j]+AL2[j])
  
  Chum <- subset(new, new$Species=="Chum")
  ChuL1[j]<-sum(Chum$ven == "negative",na.rm=TRUE) #1553
  ChuL2[j]<-sum(Chum$ven == "positive",na.rm=TRUE) #63
  ChuL3[j]<-ChuL2[j]/(ChuL1[j]+ChuL2[j])
  
  Pink <- subset(new, new$Species=="Pink")
  PL1[j]<-sum(Pink$ven == "negative",na.rm=TRUE) #1553
  PL2[j]<-sum(Pink$ven == "positive",na.rm=TRUE) #63
  PL3[j]<-PL2[j]/(PL1[j]+PL2[j])
  dL[j] <-(i)
  j=j+1
}


d<-rep.int(dL, 7)

proportion1= c(C3,CH3,H3,S3,A3,Chu3,P3)
proportion2= c(CL3,CHL3,HL3,SL3,AL3,ChuL3,PL3)
totals1<-c(C1+C2, CH1+CH2, H1+H2, S1+S2,A1+A2,Chu1+Chu2,P1+P2)
totals2<-c(CL1+CL2, CHL1+CHL2, HL1+HL2, SL1+SL2,AL1+AL2,ChuL1+ChuL2,PL1+PL2)
samp =   c(rep.int("Coho", 3), rep.int("Chinook", 3),rep.int("Herring",3), rep.int("Sockeye",3),rep.int("Atlantic", 3),rep.int("Chum", 3),rep.int("Pink", 3))
myd <- data.frame(   Region  = dL, samp = samp, no_LOD= 100*(proportion1-proportion2), LOD= 100*c(CL3,CHL3,HL3,SL3,AL3,ChuL3,PL3))


# reshaping data to long form for ggplot2 
meltd<- melt(myd)
sd1<-sqrt((proportion1*(1-proportion1))/totals1)
sd2<-sqrt((proportion2*(1-proportion2))/totals2)
totals<-c(totals1,totals2)
sd<-c(sd1,sd2)*100
ci<-1.96*(sd)
meltd<-data.frame(meltd, proportion2=proportion2*100, ci=ci)
#change this for each graph
meltd$proportion2[(22:42)]=0
t<-rep(NaN, length(totals2))
tot<-c(totals2,t)

meltd<-data.frame(meltd, final=(meltd$value+meltd$proportion2),tot)

meltd$Region<- factor(meltd$Region, levels = c("Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec","Jan","Feb"))

for(i in 1: nrow(meltd)){
  if (is.na(meltd$final[i])){
    meltd$tot[i]=0
  } else if (meltd$final[i]!=0){
    meltd$tot[i]="NaN"
  }
}

q<-ggplot(meltd, aes(x=Region, y=value, fill=variable)) +geom_bar(stat="identity") + facet_grid(~samp) + theme(axis.text.x=element_text(color = "black", size=8, angle=90, vjust=.3, hjust=0.8))+scale_y_continuous(expand = c(0, 0), limits = c(0,100))+geom_errorbar(aes(ymin= pmax((final-ci), 0), ymax=final+ci), width=.2,position=position_dodge(.9))+labs(x =" ", y = "Percent positive")+geom_text(aes(y=final, label=as.integer(tot)),vjust=-1,nudge_x = 0.12, color="black", size=2.5) 
q+theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())


#YEARS>2007
#Same plot but with modification for years

C3<-numeric(2)
C1<-numeric(2)
C2<-numeric(2)
CH3<-numeric(2)
CH1<-numeric(2)
CH2<-numeric(2)
H3<-numeric(2)
H1<-numeric(2)
H2<-numeric(2)
S3<-numeric(2)
S1<-numeric(2)
S2<-numeric(2)
d<-numeric(2)
A3<-numeric(2)
A1<-numeric(2)
A2<-numeric(2)
Chu3<-numeric(2)
Chu1<-numeric(2)
Chu2<-numeric(2)
P3<-numeric(2)
P1<-numeric(2)
P2<-numeric(2)
j=1
for(i in levels(ENVC$Year)){
  if (i>2007){
    new<-subset(ENVC, ENVC$Year==i)
    Coho <- subset(new, new$Species=="Coho")
    C1[j]<-sum(Coho$ven == "negative",na.rm=TRUE) #1553
    C2[j]<-sum(Coho$ven == "positive",na.rm=TRUE) #63
    C3 [j]<-C2[j]/(C1[j]+C2[j])
    
    Chinook <- subset(new, new$Species=="Chinook")
    CH1[j]<-sum(Chinook$ven == "negative",na.rm=TRUE) #4842
    CH2[j]<-sum(Chinook$ven == "positive",na.rm=TRUE) #380 
    CH3[j]<-CH2[j]/(CH1[j]+CH2[j])
    
    Herring <- subset(new, new$Species=="Herring")
    H1[j]<-sum(Herring$ven == "negative",na.rm=TRUE) #165
    H2[j]<-sum(Herring$ven == "positive",na.rm=TRUE) #25
    H3[j]<-H2[j]/(H1[j]+H2[j])
    
    Sockeye <- subset(new, new$Species=="Sockeye")
    S1[j]<-sum(Sockeye$ven == "negative",na.rm=TRUE) #2841
    S2[j]<-sum(Sockeye$ven == "positive",na.rm=TRUE) #225
    S3[j]<-S2[j]/(S1[j]+S2[j])
    
    Atlantic <- subset(new, new$Species=="Atlantic")
    A1[j]<-sum(Atlantic$ven == "negative",na.rm=TRUE) #1553
    A2[j]<-sum(Atlantic$ven == "positive",na.rm=TRUE) #63
    A3[j]<-A2[j]/(A1[j]+A2[j])
    
    Chum <- subset(new, new$Species=="Chum")
    Chu1[j]<-sum(Chum$ven == "negative",na.rm=TRUE) #1553
    Chu2[j]<-sum(Chum$ven == "positive",na.rm=TRUE) #63
    Chu3[j]<-Chu2[j]/(Chu1[j]+Chu2[j])
    
    Pink <- subset(new, new$Species=="Pink")
    P1[j]<-sum(Pink$ven == "negative",na.rm=TRUE) #1553
    P2[j]<-sum(Pink$ven == "positive",na.rm=TRUE) #63
    P3[j]<-P2[j]/(P1[j]+P2[j])
    d[j] <-(i)
    j=j+1
  }
}

CL3<-numeric(2)
CL1<-numeric(2)
CL2<-numeric(2)
CHL3<-numeric(2)
CHL1<-numeric(2)
CHL2<-numeric(2)
HL3<-numeric(2)
HL1<-numeric(2)
HL2<-numeric(2)
SL3<-numeric(2)
SL1<-numeric(2)
SL2<-numeric(2)
dL<-numeric(2)
AL3<-numeric(2)
AL1<-numeric(2)
AL2<-numeric(2)
ChuL3<-numeric(2)
ChuL1<-numeric(2)
ChuL2<-numeric(2)
PL3<-numeric(2)
PL1<-numeric(2)
PL2<-numeric(2)

j=1
for(i in levels(ENVCL$Year)){
  if (i>2007){
    new<-subset(ENVCL, ENVCL$Year==i)
    Coho <- subset(new, new$Species=="Coho")
    CL1[j]<-sum(Coho$ven == "negative",na.rm=TRUE) #1553
    CL2[j]<-sum(Coho$ven == "positive",na.rm=TRUE) #63
    CL3[j]<-CL2[j]/(CL1[j]+CL2[j])
    
    Chinook <- subset(new, new$Species=="Chinook")
    CHL1[j]<-sum(Chinook$ven == "negative",na.rm=TRUE) #4842
    CHL2[j]<-sum(Chinook$ven == "positive",na.rm=TRUE) #380 
    CHL3[j]<-CHL2[j]/(CHL1[j]+CHL2[j])
    
    Herring <- subset(new, new$Species=="Herring")
    HL1[j]<-sum(Herring$ven == "negative",na.rm=TRUE) #165
    HL2[j]<-sum(Herring$ven == "positive",na.rm=TRUE) #25
    HL3[j]<-HL2[j]/(HL1[j]+HL2[j])
    
    Sockeye <- subset(new, new$Species=="Sockeye")
    SL1[j]<-sum(Sockeye$ven == "negative",na.rm=TRUE) #2841
    SL2[j]<-sum(Sockeye$ven == "positive",na.rm=TRUE) #225
    SL3[j]<-SL2[j]/(SL1[j]+SL2[j])
    
    Atlantic <- subset(new, new$Species=="Atlantic")
    AL1[j]<-sum(Atlantic$ven == "negative",na.rm=TRUE) #1553
    AL2[j]<-sum(Atlantic$ven == "positive",na.rm=TRUE) #63
    AL3[j]<-AL2[j]/(AL1[j]+AL2[j])
    
    Chum <- subset(new, new$Species=="Chum")
    ChuL1[j]<-sum(Chum$ven == "negative",na.rm=TRUE) #1553
    ChuL2[j]<-sum(Chum$ven == "positive",na.rm=TRUE) #63
    ChuL3[j]<-ChuL2[j]/(ChuL1[j]+ChuL2[j])
    
    Pink <- subset(new, new$Species=="Pink")
    PL1[j]<-sum(Pink$ven == "negative",na.rm=TRUE) #1553
    PL2[j]<-sum(Pink$ven == "positive",na.rm=TRUE) #63
    PL3[j]<-PL2[j]/(PL1[j]+PL2[j])
    dL[j] <-(i)
    j=j+1
  }
}


d<-rep.int(dL, 11)

proportion1= c(C3,CH3,H3,S3,A3,Chu3,P3)
proportion2= c(CL3,CHL3,HL3,SL3,AL3,ChuL3,PL3)
totals1<-c(C1+C2, CH1+CH2, H1+H2, S1+S2,A1+A2,Chu1+Chu2,P1+P2)
totals2<-c(CL1+CL2, CHL1+CHL2, HL1+HL2, SL1+SL2,AL1+AL2,ChuL1+ChuL2,PL1+PL2)
samp =   c(rep.int("Coho", 11), rep.int("Chinook", 11),rep.int("Herring",11), rep.int("Sockeye",11),rep.int("Atlantic", 11),rep.int("Chum", 11),rep.int("Pink", 11))
myd <- data.frame(   Region  = dL, samp = samp, no_LOD= 100*(proportion1-proportion2), LOD= 100*c(CL3,CHL3,HL3,SL3,AL3,ChuL3,PL3))


# reshaping data to long form for ggplot2 
meltd<- melt(myd)
sd1<-sqrt((proportion1*(1-proportion1))/totals1)
sd2<-sqrt((proportion2*(1-proportion2))/totals2)
totals<-c(totals1,totals2)
sd<-c(sd1,sd2)*100
ci<-1.96*(sd)
meltd<-data.frame(meltd, proportion2=proportion2*100, ci=ci)
#change this for each graph
meltd$proportion2[(78:154)]=0
t<-rep(NaN, length(totals2))
tot<-c(totals2,t)

meltd<-data.frame(meltd, final=(meltd$value+meltd$proportion2),tot)

for(i in 1: nrow(meltd)){
  if (is.na(meltd$final[i])){
    meltd$tot[i]=0
  } else if (meltd$final[i]!=0){
    meltd$tot[i]="NaN"
  }
}
r<-ggplot(meltd, aes(x=Region, y=value, fill=variable)) +geom_bar(stat="identity") + facet_grid(~samp) + theme(axis.text.x=element_text(color = "black", size=8.5, angle=90, vjust=.3, hjust=0.8))+scale_y_continuous(expand = c(0, 0), limits = c(0,110))+geom_errorbar(aes(ymin= pmax((final-ci), 0), ymax=final+ci), width=.2,position=position_dodge(.9))+labs(x =" ", y = "Percent positive")+geom_text(aes(y=final, label=as.integer(tot)),vjust=-1,nudge_x = 0.12, color="black", size=2)
r+theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())


#NEWPLOT: PREVALENCE BY SPECIES
C1=numeric(1)
C1L=numeric(1)
Sp=numeric(1)
SpL=numeric(1)
SD2=numeric(1)
SD3=numeric(1)
N1=numeric(1)
N2=numeric(1)
W=numeric(1)
j=1


for(i in levels(ENVC$Species)){
  new<-subset(ENVC, ENVC$Species==i)
  A<-sum(new$ven == "positive",na.rm=TRUE) 
  B<-sum(new$ven == "negative",na.rm=TRUE)+A
  p<-A/B
  C1[j]<-p
  Sp[j]<-i
  N1[j]<-B
  W[j]<-"noLOD"
  SD2[j]<-sqrt((p*(1-p))/B)
  j=j+1
}
ci2<-1.96*SD2
j=1
for(k in levels(ENVCL$Species)){
  new2<-subset(ENVCL, ENVCL$Species==k)
  A<-sum(new2$ven == "positive",na.rm=TRUE) 
  B<-sum(new2$ven == "negative",na.rm=TRUE)+A
  p<-A/B
  C1L[j]<-p
  N2[j]<-B
  SpL[j]<-"LOD"
  SD3[j]<-sqrt((p*(1-p))/B)
  j=j+1
}
ci3<-1.96*SD3
ci<-c(ci2,ci3)
Species<-c(Sp,Sp)
Proportion<-c(C1,C1L)
L<-c(W,SpL)
df<-data.frame(Species,C1,C1L,ci2,ci3,N1)

q<-ggplot(data=df,aes(x=Species))+geom_bar(aes(y=C1),stat="identity",position ="identity",fill='pink') +geom_bar(aes(y=C1L),stat="identity",position ="identity",fill='lightblue')
q<-q+geom_errorbar(aes(ymin= pmax((C1-ci2), 0), ymax=C1+ci2), width=.2,position=position_nudge(-.3))+geom_errorbar(aes(ymin= pmax((C1L-ci3), 0), ymax=C1L+ci3),width=.2,position=position_nudge(.3))+theme(axis.text.x=element_text(color = "black", size=8, angle=90))+scale_y_continuous(expand = c(0, 0), limits = c(0,0.8))+geom_text(aes(y=C1, label=as.integer(N1)), vjust=-.8, color="black", size=3) +labs(x =" ", y = "Proportion Positive")
q+theme_bw() +theme(axis.line = element_line(colour = "black"),panel.grid.major = element_blank(),panel.grid.minor = element_blank(),panel.border = element_blank(),panel.background = element_blank())

#NEWPLOT: LOAD BY SPECIES
Load <- data.frame(venval=ENVC$venval,LOD=ENVC$LOD, Sp=ENVC$Species, Fish=ENVC$Fish)
LoadL <- data.frame(venval=ENVCL$venval,LOD=ENVCL$LOD, Sp=ENVCL$Species,Fish=ENVCL$Fish)
tester<-merge(Load, LoadL, by=c("Fish"))
tester<-subset(tester,tester$venval.x>0,na.rm=TRUE)

LoadL<-subset(LoadL,LoadL$venval>0,na.rm=TRUE)
Load<-subset(Load,Load$venval>0,na.rm=TRUE)

Load$Sp<-factor(Load$Sp)
LoadL$Sp<-factor(LoadL$Sp)
Load$Sp<-droplevels(Load$Sp)
LoadL$Sp<-droplevels(LoadL$Sp)
tester$venval.y<-replace(tester$venval.y,is.na(tester$venval.y),0)

tester$LOD<-character(length=2303)
for(i in 1:nrow(tester)){
  if (tester$venval.x[i]==tester$venval.y[i]){
    tester$LOD[i]<-"#00BFC4"
    }else
    tester$LOD[i]<-"#F8766D"
}
Np<-0
j=1
tester$Sp.x<-droplevels(tester$Sp.x)
for(i in levels(tester$Sp.x)){
  news<-subset(tester, tester$Sp.x==i)
  Np[j]<-nrow(news)
  j=j+1
}


p <- ggplot(tester, mapping = aes(x = tester$Sp.x, y = tester$venval.x))+ geom_violin()+scale_y_log10(breaks = scales::trans_breaks("log10", function(x) 10^x),labels = scales::trans_format("log10", scales::math_format(10^.x)))+ annotation_logticks(sides="l")

violin.layer <- geom_violin()
jitter.layer <- geom_jitter(width=0.25, height=0, alpha=0.5, size=0.75,color=tester$LOD)
p+jitter.layer+labs(x =" ", y = "ENV Copy")+theme_bw() +theme(axis.line = element_line(colour = "black"),panel.grid.major = element_blank(),panel.grid.minor = element_blank(),panel.border = element_blank(),panel.background = element_blank()) + annotate("text", label = as.integer(Np), x =c(1:7), y = 0.01, size = 3, colour = "black")


#NEWPLOT WITH FACET GRIDS
#Instructions:
#1)Change category (last part of df to desired (2 places))
#2) Change ggplot category to desired (1 place)
library(easyGgplot2)
Load<-0
LoadL<-0
tester<-0
Load <- data.frame(venval=ENVC$venval,LOD=ENVC$LOD, Sp=ENVC$Species, Fish=ENVC$Fish,Sex=ENVC$Sex)
LoadL <- data.frame(venval=ENVCL$venval,LOD=ENVCL$LOD, Sp=ENVCL$Species,Fish=ENVCL$Fish,Sex=ENVCL$Sex)
tester<-merge(Load, LoadL, by=c("Fish"))
tester<-subset(tester,tester$venval.x>0,na.rm=TRUE)

LoadL<-subset(LoadL,LoadL$venval>0,na.rm=TRUE)
Load<-subset(Load,Load$venval>0,na.rm=TRUE)

Load$Sp<-factor(Load$Sp)
LoadL$Sp<-factor(LoadL$Sp)
Load$Sp<-droplevels(Load$Sp)
LoadL$Sp<-droplevels(LoadL$Sp)
tester$venval.y<-replace(tester$venval.y,is.na(tester$venval.y),0)

tester$LOD<-character(length=2303)
for(i in 1:nrow(tester)){
  if (tester$venval.x[i]==tester$venval.y[i]){
    tester$LOD[i]<-"#00BFC4"
  }else
    tester$LOD[i]<-"#F8766D"
}
Np<-0
j=1
tester$Sp.x<-droplevels(tester$Sp.x)
for(i in levels(tester$Sp.x)){
  news<-subset(tester, tester$Sp.x==i)
  Np[j]<-nrow(news)
  j=j+1
}
#tester$Region.x<- factor(tester$Region.x, levels = c("AK","Northern","VIN","VIS","WA","WCVI","FW"))
#tester$Season.x<- factor(tester$Season.x, levels = c("Spring","Summer","Fall","Overwinter"))

t<-ggplot2.violinplot(data=tester, xName='Sex.x',yName='venval.x', legendPosition="top",faceting=TRUE, facetingVarNames="Sp.x",facetingDirection="horizontal",xTickLabelFont=c(14,"plain", "#993333"))+scale_y_log10(breaks = scales::trans_breaks("log10", function(x) 10^x),labels = scales::trans_format("log10", scales::math_format(10^.x)))+ annotation_logticks(sides="l")
t<-t+ theme(axis.text.x=element_text(color = "black", size=8, angle=30, vjust=.3, hjust=0.8))+labs(x =" ", y = "ENV Copy")+theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())
violin.layer <- geom_violin()
jitter.layer <- geom_jitter(width=0.15, height=0.05, alpha=0.5, size=0.75,color=tester$LOD)
t+jitter.layer


###################################ANALYSIS#############################################
#KRUSKAL-WALLIS (NON-NORMAL ANOVA)
#change SP.y category to test for different things
kruskal.test(venval.y ~ Sp.y, data = tester)
#POST-HOC: Dunn test
library(FSA)
PT = dunnTest(venval.y ~ Sp.y, data = tester, method="bh")  
PT

#CORRELATION
#first run plot code for months --> meltd (but don't run last loop to get rid of sample sizes for non-zero proportions)
meltd$tot<-c(totals2,totals2)
subS<-subset(meltd, meltd$samp=="Sockeye")
subS<-subset(subS, subS$variable=="LOD")
subA<-subset(meltd, meltd$samp=="Atlantic")
subA<-subset(subA, subA$variable=="LOD")
subC<-subset(meltd, meltd$samp=="Chinook")
subC<-subset(subC, subC$variable=="LOD")
sock<-subS$final[c(1,2,6,7,9,10,11,12)]
atl<-subA$final[c(1,2,6,7,9,10,11,12)]
plot(subA$final,subS$final)
cor(atl,sock, use="complete.obs", method="spearman") 
cor.test(atl,sock, method=c("spearman"), exact=FALSE)

#GLMER MODEL
adata3<-data.frame(ENVCL$ven,ENVCL$SWFW, ENVCL$Species,ENVCL$Catch_Region, ENVCL$SEASON1, ENVCL$Sex, ENVCL$Year, ENVCL$HatcheryWild, ENVCL$SmAd, ENVCL$Mass)
adata3<-subset(adata3, adata3$ENVCL.ven!="NaN")
adata3$ENVCL.ven<-droplevels(adata3$ENVCL.ven)
library(multcomp)

Laplace1 <- glmer(ENVCL.ven ~ ENVCL.SWFW + (1 | ENVCL.Catch_Region) + (1 | ENVCL.Species) + (1 | ENVCL.SmAd)+(1 | ENVCL.SEASON1)+(1|ENVCL.HatcheryWild) +(1 | ENVCL.Year),data = adata3, family = binomial(link = "logit")) 
summary(glht(Laplace1, linfct = mcp(ENVCL.SWFW = "Tukey")), test = adjusted("holm"))

#CHI-SQUARED
Sex<-table(ENVCL$Sex, ENVCL$ven)
Sex<-Sex[,2:3]
Smatrix = as.matrix((Sex),header=TRUE, row.names=1)
chisq.test(Smatrix)

SWFW<-table(ENVCL$SWFW, ENVCL$ven)
SWFW<-SWFW[,2:3]
SWmatrix = as.matrix((SWFW),header=TRUE, row.names=1)
chisq.test(SWmatrix)

SMAD<-table(ENVCL$SmAd, ENVCL$ven)
SMAD<-SMAD[,2:3]
SMmatrix = as.matrix((SMAD),header=TRUE, row.names=1)
chisq.test(SMmatrix)
PTSM = pairwiseNominalIndependence(SMmatrix,fisher = FALSE,gtest  = FALSE,chisq  = TRUE,digits = 3)

#ENV<-subset(ENVCL,ENVCL$Species=="Chinook")
#ENV1<-subset(ENVCL,ENVCL$Species=="Coho")
Hatch<-table(ENV$HatcheryWild, ENV$ven)
Hatch<-Hatch[,2:3]
Hmatrix = as.matrix((Hatch),header=TRUE, row.names=1)
fisher.test(Hmatrix,alternative="two.sided")
chisq.test(Hmatrix)
PTH = pairwiseNominalIndependence(Hmatrix,fisher = FALSE,gtest  = FALSE,chisq  = TRUE,digits = 3)

Species<-table(ENVCL$Species, ENVCL$ven)
Species<-Species[,2:3]
Spmatrix = as.matrix((Species),header=TRUE, row.names=1)
chisq.test(Spmatrix)

#exclude pink and chum
PTS = pairwiseNominalIndependence(Spmatrix,fisher = FALSE,gtest  = FALSE,chisq  = TRUE,digits = 3)
#or do fisher's exact
PTS = pairwiseNominalIndependence(Spmatrix,fisher = TRUE,gtest  = FALSE,chisq  = FALSE,digits = 3)


#CHI SQUARED PLOTS
##Species
sdp<-0
y<-rowSums (Spmatrix, na.rm = FALSE, dims = 1)
z<-Spmatrix[,2]/y
for(i in 1:length(z)) {
  a<-((z[i]*(1-z[i])/y[i]))
  sdp[i]<-sqrt(a)
  a=0}
cip<-1.96*(sdp)

f<-barplot(z, col="skyblue", ylim=c(0,0.5), ylab="Proportion positive")
error.bar <- function(x, y, upper, lower=upper, length=0.1,...){
  if(length(x) != length(y) | length(y) !=length(lower) | length(lower) != length(upper))
    stop("vectors must be same length")
  arrows(x,y+upper, x, y-lower, angle=90, code=3, length=length, ...)
}
error.bar(f, z, cip)
#lines(x = c(0,10), y = c(0.052,0.052))

###SEX
y<-rowSums (Smatrix, na.rm = FALSE, dims = 1)
z<-Smatrix[,2]/y
sdp<-0
for(i in 1:length(z)) {
  a<-((z[i]*(1-z[i])/y[i]))
  sdp[i]<-sqrt(a)
  a=0}
cip<-1.96*(sdp)
f<-barplot(z, col="skyblue", ylim=c(0,0.5), ylab="Proportion positive")
error.bar(f, z, cip)

##Catchregion
y<-rowSums (Cmatrix, na.rm = FALSE, dims = 1)
z<-Cmatrix[,2]/y
sdp<-0
for(i in 1:length(z)) {
  a<-((z[i]*(1-z[i])/y[i]))
  sdp[i]<-sqrt(a)
  a=0}
cip<-1.96*(sdp)
f<-barplot(z, col="skyblue", ylim=c(0,0.5), ylab="Proportion positive")
error.bar(f, z, cip)

###Hatch
y<-rowSums (Hmatrix, na.rm = FALSE, dims = 1)
z<-Hmatrix[,2]/y
sdp<-0
for(i in 1:length(z)) {
  a<-((z[i]*(1-z[i])/y[i]))
  sdp[i]<-sqrt(a)
  a=0}
cip<-1.96*(sdp)
f<-barplot(z, col="skyblue", ylim=c(0,0.25), ylab="Proportion positive")
error.bar(f, z, cip)

###SMAD
y<-rowSums (SMmatrix, na.rm = FALSE, dims = 1)
z<-SMmatrix[,2]/y
sdp<-0
for(i in 1:length(z)) {
  a<-((z[i]*(1-z[i])/y[i]))
  sdp[i]<-sqrt(a)
  a=0}
cip<-1.96*(sdp)
f<-barplot(z, col="skyblue", ylim=c(0,0.25), ylab="Proportion positive")
error.bar(f, z, cip)


###SWFW
y<-rowSums (SWmatrix, na.rm = FALSE, dims = 1)
z<-SWmatrix[,2]/y
sdp<-0
for(i in 1:length(z)) {
  a<-((z[i]*(1-z[i])/y[i]))
  sdp[i]<-sqrt(a)
  a=0}
cip<-1.96*(sdp)
f<-barplot(z, col="skyblue", ylim=c(0,0.5), ylab="Proportion positive")
error.bar(f, z, cip)
